//#region src/panzoom/type.d.ts
interface PanZoomOptions {
  zoomFactor?: number;
  /**
  * @default 5
  */
  maxZoom?: number;
  /**
  * @default 0.2
  */
  minZoom?: number;
  onTransform?: (transform: Transform) => void;
}
interface Transform {
  x: number;
  y: number;
  scale: number;
}
//#endregion
//#region src/panzoom/core.d.ts
type PanZoomReturn = {
  destroy: () => void;
};
/**
* @linkcode https://github.com/GreatAuk/utopia-utils/blob/main/packages/dom/src/panzoom/index.ts
*/
declare function panzoom(target: HTMLElement, {
  zoomFactor,
  maxZoom,
  minZoom,
  onTransform
}?: PanZoomOptions): PanZoomReturn;
//#endregion
//#region src/canUseDom.d.ts
/**
* The function checks if the DOM (Document Object Model) can be used in the current environment.
* @returns a boolean value indicating whether the DOM (Document Object Model) can be used.
* @linkcode https://github.com/GreatAuk/utopia-utils/blob/main/packages/dom/src/canUseDom.ts
*/
declare function canUseDom(): boolean;
//#endregion
//#region src/domContains.d.ts
/**
* The function checks if a given node is contained within a root node, using either the native
* `contains` method or a fallback method for older browsers.
* @param {Node | null | undefined} root - The `root` parameter represents the root node of a tree or
* subtree.
* @param {Node | null} n - The parameter `n` represents a Node object that we want to check if it is
* contained within the `root` Node object.
* @returns a boolean value. It returns `true` if the `root` node contains the `n` node, and `false`
* otherwise.
* @linkcode https://github.com/GreatAuk/utopia-utils/blob/main/packages/dom/src/contains.ts
*/
declare function domContains(root: Node | null | undefined, n: Node | null): boolean;
//#endregion
//#region src/dynamicCSS.d.ts
type ContainerType = Element | ShadowRoot;
type Prepend = boolean | "queue";
type AppendType = "prependQueue" | "append" | "prepend";
interface Options {
  attachTo?: ContainerType;
  csp?: {
    nonce?: string;
  };
  prepend?: Prepend;
  /**
  * Config the `priority` of `prependQueue`. Default is `0`.
  * It's useful if you need to insert style before other style.
  */
  priority?: number;
  mark?: string;
}
declare function injectCSS(css: string, option?: Options): HTMLStyleElement | null;
declare function removeCSS(key: string, option?: Options): void;
/**
* manually clear container cache to avoid global cache in unit testes
*/
declare function clearContainerCache(): void;
/**
* Update CSS text in style element
* @param css CSS text
* @param key style key
* @param option Options
* @returns style element
* @fork https://github.com/react-component/util/blob/master/src/Dom/dynamicCSS.ts
* @linkcode https://github.com/GreatAuk/utopia-utils/blob/main/packages/dom/src/dynamicCSS.ts
* @example
* ```js
* updateCSS('body { color: red }', 'my-style')
* ```
*/
declare function updateCSS(css: string, key: string, option?: Options): HTMLStyleElement | undefined;
//#endregion
//#region src/isAlipay.d.ts
/**
* Check if the current environment is Alipay. (支付宝)
* @returns A boolean value.
* @linkcode https://github.com/GreatAuk/utopia-utils/blob/main/packages/dom/src/isAlipay.ts
*/
declare function isAlipay(): boolean;
//#endregion
//#region src/isAndroid.d.ts
/**
* Returns a boolean value indicating whether the current platform is Android.
* @returns A boolean value.
* @linkcode https://github.com/GreatAuk/utopia-utils/blob/main/packages/dom/src/isAndroid.ts
*/
declare function isAndroid(): boolean;
//#endregion
//#region src/isIOS.d.ts
/**
* If the user agent string contains the word 'iPad', 'iPhone', or 'iPod', then we're on iOS.
* @returns A boolean value.
* @linkcode https://github.com/GreatAuk/utopia-utils/blob/main/packages/dom/src/isIOS.ts
*/
declare function isIOS(): boolean;
//#endregion
//#region src/isMobile.d.ts
/**
* detect current environment is a mobile device
* @returns A boolean value.
* @linkcode https://github.com/GreatAuk/utopia-utils/blob/main/packages/dom/src/isMobile.ts
*/
declare function isMobile(): boolean;
//#endregion
//#region src/isWeixin.d.ts
/**
* Check if the current environment is Weixin. (微信)
* @returns A boolean value.
* @linkcode https://github.com/GreatAuk/utopia-utils/blob/main/packages/dom/src/isWeixin.ts
*/
declare function isWeixin(): boolean;
//#endregion
//#region src/loadCSS.d.ts
/**
* Options for {@link loadCSS} function
*/
interface LoadCSSOptions {
  /**
  * Media query for styles to apply
  * @example 'print', 'all', 'screen and (max-width: 768px)' and etc.
  */
  media?: string;
  /**
  * Add custom attribute to the script tag
  *
  */
  attrs?: Record<string, string>;
}
/**
* return type of {@link loadCSS} function
*/
interface LoadCSSReturn {
  unload: () => void;
  linkTag: HTMLLinkElement;
}
/**
* It loads a CSS file into the page
* @param {string} path - the path to the CSS file
* @param {LoadCSSOptions} [options] - {
* @returns An object with two properties:
*   - unload: a function that removes the script tag
*   - linkTag: the link tag that was created
* @linkcode https://github.com/GreatAuk/utopia-utils/blob/main/packages/dom/src/loadCSS.ts
*/
declare function loadCSS(path: string, options?: LoadCSSOptions): LoadCSSReturn;
//#endregion
//#region src/loadScript.d.ts
/**
* options type for {@link loadScript} function
*/
interface LoadScriptOptions {
  /**
  * Add `async` attribute to the script tag
  * @default true
  */
  async?: boolean;
  /**
  * Add `defer` attribute to the script tag
  */
  defer?: boolean;
  /**
  * Script type
  *
  * @default 'text/javascript'
  * @see https://developer.mozilla.org/zh-CN/docs/Web/HTML/Element/script#attr-type
  */
  type?: string;
  crossOrigin?: "anonymous" | "use-credentials";
  /**
  * @see https://developer.mozilla.org/zh-CN/docs/Web/HTML/Element/script#attr-referrerpolicy
  */
  referrerPolicy?: "no-referrer" | "no-referrer-when-downgrade" | "origin" | "origin-when-cross-origin" | "same-origin" | "strict-origin" | "strict-origin-when-cross-origin" | "unsafe-url";
  noModule?: boolean;
  /**
  * Add custom attribute to the script tag
  *
  */
  attrs?: Record<string, string>;
  /**
  * Append the script tag to the document.head or document.body
  * @default 'head'
  */
  appendPosition?: "head" | "body";
  onStatusChange?: (status: "loading" | "loaded" | "error") => void;
}
/**
* return type of {@link loadScript} function
*/
interface LoadScriptReturn {
  unload: () => void;
  scriptTag: HTMLScriptElement;
}
/**
* It loads a script tag into the DOM
* @param {string} src - The URL of the script to load.
* @param {LoadScriptOptions} [options] - LoadScriptOptions
* @returns An object with two properties:
*   - unload: a function that removes the script tag
*   - scriptTag: the script tag that was created
* @linkcode https://github.com/GreatAuk/utopia-utils/blob/main/packages/dom/src/loadScript.ts
*/
declare function loadScript(src: string, options?: LoadScriptOptions): LoadScriptReturn;
//#endregion
//#region src/setCssVar.d.ts
/**
* The function sets CSS variables on the root element of a document using the provided variables
* object.
* @param variables - The `variables` parameter is an object that contains key-value pairs representing
* CSS variable names and their corresponding values.
* @param root - The `root` parameter is an optional parameter that represents the root element where
* the CSS variables should be set. By default, it is set to `window?.document?.documentElement`, which
* refers to the root element of the current document.
* @linkcode https://github.com/GreatAuk/utopia-utils/blob/main/packages/dom/src/setCssVar.ts
* @example
* ```ts
* setCssVar({ '--color': 'red', '--size': '10px' })
* setCssVar({ '--color': 'red', '--size': '10px' }, document.body)
* ```
*/
declare function setCssVar(variables: Record<string, string | null>, root?: HTMLElement): void;
//#endregion
//#region src/waitForSelector.d.ts
/**
* Options for {@link waitForSelector}
*/
interface WaitForOptions {
  /** Maximum time to wait in milliseconds, default is 30000 (30s) */
  timeoutMillisecond?: number;
  /**
  * Instructs the user agent to observe a given target (a node)
  * @default document.body
  */
  target?: Node;
}
/**
* waits for an element to appear in the DOM
* @param {string} selector - The CSS selector to wait for.
* @param {WaitForOptions} [options]
* @returns A promise that resolves to an element that matches the selector.
* @linkcode https://github.com/GreatAuk/utopia-utils/blob/main/packages/dom/src/waitForSelector.ts
*/
declare function waitForSelector<T extends Element>(selector: string, options?: WaitForOptions): Promise<T | null>;
//#endregion
//#region src/webp.d.ts
/**
* Checks the browser's support for specific WebP features.
* @param feature The WebP feature to check for. Defaults to 'lossy'.
* @returns A promise that resolves to a boolean indicating whether the feature is supported.
* @link Official way by Google: https://developers.google.com/speed/webp/faq?hl=zh-cn#how_can_i_detect_browser_support_for_webp
*/
declare function checkWebpFeature(feature?: "lossy" | "lossless" | "alpha" | "animation"): Promise<boolean>;
/**
* Checks the browser's support for WebP image format.
* @returns A promise that resolves to a boolean indicating whether WebP is supported.
*/
declare function checkWebpSupport(): Promise<boolean>;
//#endregion
//#region src/styleUtil.d.ts
/**
* Split the className string into an array of class names, and filter out any empty strings.
* @param [cls] - The className string
*/
declare function classNameToArray(cls?: string): string[];
declare function hasClass(el: Element, cls: string): boolean;
declare function addClass(el: Element, cls: string): void;
declare function removeClass(el: Element, cls: string): void;
//#endregion
export { AppendType, ContainerType, Prepend, addClass, canUseDom, checkWebpFeature, checkWebpSupport, classNameToArray, clearContainerCache, domContains, hasClass, injectCSS, isAlipay, isAndroid, isIOS, isMobile, isWeixin, loadCSS, loadScript, panzoom, removeCSS, removeClass, setCssVar, updateCSS, waitForSelector };
//# sourceMappingURL=index.d.mts.map